@@ -30,7 +30,7 @@ def isserviceactive(SERVICENAME):
 def isserviceenabled(SERVICENAME):
     output = subprocess.check_output("systemctl status %s" % SERVICENAME, shell=True)
     output = output.decode()
-    if "enabled; vendor preset: enabled" in output and os.path.isfile("/usr/lib/systemd/system/%s.service" % SERVICENAME):
+    if "enabled; vendor preset" in output and os.path.isfile("/usr/lib/systemd/system/%s.service" % SERVICENAME):
         print(bcolors.OKGREEN + SERVICENAME + " Service is enabled"  + bcolors.ENDC)
     else: 
         print(bcolors.FAIL + SERVICENAME + " Service is not enabled"  + bcolors.ENDC)
